"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.decrypt = exports.encrypt = exports.DecryptionFailedError = void 0;
const crypto_1 = require("crypto");
const node_crypto_1 = require("node:crypto");
class DecryptionFailedError extends Error {
    constructor() {
        super('Decryption failed');
    }
}
exports.DecryptionFailedError = DecryptionFailedError;
async function encrypt(value, password) {
    const iv = (0, crypto_1.randomBytes)(16);
    const salt = (0, crypto_1.randomBytes)(16);
    const key = await generateKey(password, salt);
    const cipher = (0, crypto_1.createCipheriv)('aes-256-cbc', key, iv);
    const encryptedData = Buffer.concat([
        cipher.update(value, 'utf8'),
        cipher.final(),
    ]);
    const encryptedMessage = Buffer.concat([salt, iv, encryptedData]);
    return encryptedMessage.toString('base64');
}
exports.encrypt = encrypt;
async function decrypt(encryptedValue, password) {
    const encryptedBuffer = Buffer.from(encryptedValue, 'base64');
    const salt = encryptedBuffer.subarray(0, 16);
    const iv = encryptedBuffer.subarray(16, 32);
    const encryptedData = encryptedBuffer.subarray(32);
    const key = await generateKey(password, salt);
    let decryptedData;
    try {
        const decipher = (0, crypto_1.createDecipheriv)('aes-256-cbc', key, iv);
        decryptedData = Buffer.concat([
            decipher.update(encryptedData),
            decipher.final(),
        ]);
    }
    catch (error) {
        throw new DecryptionFailedError();
    }
    return decryptedData.toString('utf8');
}
exports.decrypt = decrypt;
async function generateKey(password, salt) {
    return new Promise((resolve, reject) => {
        (0, node_crypto_1.scrypt)(password, salt, 32, (err, key) => {
            if (err) {
                reject(err);
            }
            else {
                resolve(key);
            }
        });
    });
}
