"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PluginUiServer = void 0;
const plugin_ui_utils_1 = require("@homebridge/plugin-ui-utils");
const winix_1 = require("./winix");
const winix_2 = require("../winix");
const settings_1 = require("../settings");
class PluginUiServer extends plugin_ui_utils_1.HomebridgePluginUiServer {
    constructor() {
        super();
        this.service = new winix_1.WinixService(this.homebridgeStoragePath, settings_1.ENCRYPTION_KEY);
        this.onRequest('/init', this.init.bind(this));
        this.onRequest('/login', this.login.bind(this));
        this.onRequest('/discover', this.discoverDevices.bind(this));
        this.ready();
    }
    async init(auth) {
        try {
            return await this.service.init(auth);
        }
        catch (e) {
            return { needsLogin: true };
        }
    }
    async login(request) {
        try {
            return await this.service.login(request);
        }
        catch (e) {
            const message = getErrorMessage(e);
            throw new plugin_ui_utils_1.RequestError(message, { status: 400 });
        }
    }
    async discoverDevices() {
        try {
            return await this.service.discoverDevices();
        }
        catch (e) {
            if (e instanceof winix_2.UnauthenticatedError) {
                throw new plugin_ui_utils_1.RequestError('Not authenticated', { status: 401 });
            }
            const message = getErrorMessage(e);
            throw new plugin_ui_utils_1.RequestError(message, { status: 500 });
        }
    }
}
exports.PluginUiServer = PluginUiServer;
function getErrorMessage(error) {
    return error instanceof Error ? error.message : String(error);
}
function startPluginUiServer() {
    return new PluginUiServer();
}
startPluginUiServer();
